# FTP, SFTP et webdav avec Python

![tag](python)
![category](developpement)

## FTP

Il existe une librairie standard qui gère ce genre de communication

```python
from ftplib import FTP
ftp = FTP('ftp.monsite.com', 'user', 'password')  
print(ftp.dir())
# copie de fichier
f_name = "mon_fichier.txt"
f = open(f_name, 'rb')
ftp.storbinary('STOR ' + f_name, f)
f.close()
# renommer 
ftp.rename("test1", "test2")
# Creer un dossier
ftp.mkd("test")
# Supprimer un dossier
ftp.rmd("test.txt")
# Supprimer un fichier
ftp.delete("test.txt")
# Changer de dossier
connect.sendcmd('CWD test')
```

## STFP

Il est possible d'utiliser une librairie externe nomme *pysftp*

```bash
pip install pysftp
```

```python
import pysftp

with pysftp.Connection('myip', username='user', password='XXXXX') as sftp:
    for i in sftp.listdir():
        print(i)
    # sftp.cd('public'):             # temporarily chdir to public
    # sftp.put('/my/local/filename')  # upload file to public/ on remote
    # sftp.get('remote_file')         # get a remote file
```

## WebdavClient

il est possible d'installer une librairie externem nommer

```bash
apt-get install libxml2-dev libxslt-dev python-dev
apt-get install libcurl4-openssl-dev python-pycurl 
pip install webdavclient
```

```python
import webdav.client as wc
options = {
 'webdav_hostname': "https://webdav.server.ru",
 'webdav_login':    "login",
 'webdav_password': "password"
}
client = wc.Client(options)
# Checking existence of the resource
client.check("dir1/file1")
client.check("dir1")
# Get information about the resource
client.info("dir1/file1")
client.info("dir1/")
# Check free space
free_size = client.free()
# Get a list of resources
files1 = client.list()
files2 = client.list("dir1")
# Create directory
client.mkdir("dir1/dir2")
# Delete resource
client.clean("dir1/dir2")
# Copy resource
client.copy(remote_path_from="dir1/file1", remote_path_to="dir2/file1")
client.copy(remote_path_from="dir2", remote_path_to="dir3")
# Move resource
client.move(remote_path_from="dir1/file1", remote_path_to="dir2/file1")
client.move(remote_path_from="dir2", remote_path_to="dir3")
# Move resource
client.download_sync(remote_path="dir1/file1", local_path="~/Downloads/file1")
client.download_sync(remote_path="dir1/dir2/", local_path="~/Downloads/dir2/")
# Unload resource
client.upload_sync(remote_path="dir1/file1", local_path="~/Documents/file1")
client.upload_sync(remote_path="dir1/dir2/", local_path="~/Documents/dir2/")
# Publish the resource
link = client.publish("dir1/file1")
link = client.publish("dir2")
# Unpublish resource
client.unpublish("dir1/file1")
client.unpublish("dir2")
# Get the missing files
client.pull(remote_directory='dir1', local_directory='~/Documents/dir1')
# Send missing files
client.push(remote_directory='dir1', local_directory='~/Documents/dir1')
```
